aboutsummaryrefslogtreecommitdiff
path: root/engine/lib/group.php
diff options
context:
space:
mode:
authorewinslow <ewinslow@36083f99-b078-4883-b0ff-0f9b5a30f544>2010-11-14 08:04:28 +0000
committerewinslow <ewinslow@36083f99-b078-4883-b0ff-0f9b5a30f544>2010-11-14 08:04:28 +0000
commitaa5bb3f0bc17d858831412da82eef805ecafac89 (patch)
tree1a8c281c27778755bd9db83f8aa5822706a3b5db /engine/lib/group.php
parentbddba2985d89ff3ed9f52681b37cdce7a9c22bd9 (diff)
downloadelgg-aa5bb3f0bc17d858831412da82eef805ecafac89.tar.gz
elgg-aa5bb3f0bc17d858831412da82eef805ecafac89.tar.bz2
Fixes #2334: Converted viewtype => listtype and viewtypetoggle => listtypetoggle. Did my best to maintain backwards compatibility but might have missed something...
git-svn-id: http://code.elgg.org/elgg/trunk@7311 36083f99-b078-4883-b0ff-0f9b5a30f544
Diffstat (limited to 'engine/lib/group.php')
-rw-r--r--engine/lib/group.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/engine/lib/group.php b/engine/lib/group.php
index e554a44c5..def82fa9c 100644
--- a/engine/lib/group.php
+++ b/engine/lib/group.php
@@ -272,7 +272,7 @@ $order_by = "", $limit = 10, $offset = 0, $count = FALSE) {
* @param int $container_guid The GUID of the containing group
* @param int $limit The number of entities to display per page (default: 10)
* @param bool $fullview Whether or not to display the full view (default: true)
* @param bool $viewtypetoggle Whether or not to allow gallery view (default: true)
* @param bool $pagination Whether to display pagination (default: true)
*
* @return string List of parsed entities
@@ -281,7 +281,7 @@ $order_by = "", $limit = 10, $offset = 0, $count = FALSE) {
* @deprecated 1.8 Use elgg_list_entities() instead
*/
function list_entities_groups($subtype = "", $owner_guid = 0, $container_guid = 0,
-$limit = 10, $fullview = true, $viewtypetoggle = true, $pagination = true) {
+$limit = 10, $fullview = true, $listtypetoggle = true, $pagination = true) {
elgg_deprecated_notice("list_entities_groups was deprecated in 1.8. Use elgg_list_entities() instead.", 1.8);
$offset = (int) get_input('offset');
$count = get_objects_in_group($container_guid, $subtype, $owner_guid,
@@ -290,7 +290,7 @@ $limit = 10, $fullview = true, $viewtypetoggle = true, $pagination = true) {
0, "", $limit, $offset);
return elgg_view_entity_list($entities, $count, $offset, $limit,
- $fullview, $viewtypetoggle, $pagination);
+ $fullview, $listtypetoggle, $pagination);
}
/**
@@ -272,7 +272,7 @@ $order_by = "", $limit = 10, $offset = 0, $count = FALSE) {
* @param int $limit The number of entities to display per page (default: 10)
* @param bool $fullview Whether or not to display the full view (default: true)
- * @param bool $viewtypetoggle Whether or not to allow gallery view (default: true)
+ * @param bool $listtypetoggle Whether or not to allow gallery view (default: true)
* @param bool $pagination Whether to display pagination (default: true)
*